package com.example.zxweb.utils;

import com.example.zxweb.common.constant.enums.WeekEnum;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.lang3.math.NumberUtils;

import java.text.DecimalFormat;

/**
 * @Description 简单型Cron
 * @Author ZhouWenTao
 * @Date 2023/9/14 10:35
 */
public class CronLowUtil {
    public static void main(String[] args) {
        String timeType="everyDay";
        String exeTime="08:30";
        String weeklyDay="1,2,3";//周一，周二，周三
        String day="1,31";
        String startDate="2023-09-10";//开始时间
        String endDate="2023-09-30";//结束时间
        System.out.println(getCron(timeType,exeTime,weeklyDay,day,startDate,endDate));
        //cron转 显示文本
        System.out.println(cronToText(getCron(timeType,exeTime,weeklyDay,day,startDate,endDate)));
    }

    /**
     *
     * @param timeType 时间类型(everyDay:每天,weekly:每周,day:每天,date:日期段)
     * @param exeTime 执行时间(HH:mm 例：08:30)
     * @param weeklyDay 1,2,3：周一,周二，周三
     * @param day 每月的第几天,1,31  每月1日，31日
     * @param startDate 范围型，开始日期 2023-09-10
     * @param endDate 范围型，截止日期 2023-09-30
     * @return cron
     */
    public static String getCron(String timeType,String exeTime,String weeklyDay,String day,String startDate,String endDate) {
        String[] time = exeTime.split(":");
        Integer hour=Integer.parseInt(time[0]);//小时
        Integer minute=Integer.parseInt(time[1]);//分钟
        String cron=null;
        //每天
        if ("everyDay".equals(timeType)) {
            cron = String.format("0 %s %s * * ? *",minute,hour);
        } else if ("weekly".equals(timeType)) {
            //每周
            cron = String.format("0 %s %s ? * %s",minute,hour,weeklyDay);
        } else if("day".equals(timeType)){
            //单日
            cron = String.format("0 %s %s %s * ? ",minute,hour,day);
        } else if ("date".equals(timeType)){
            //日期段
            System.out.println("在"+startDate+"到"+endDate);
            cron = String.format("0 %s %s * * ? *",minute,hour);
        }
        return cron;
    }

    /**
     * 将Cron 解释成文本
     * @param cron cron
     * @return
     */
    public static String cronToText(String cron){
        if (StringUtils.isBlank(cron)) {
            return "未知";
        }
        StringBuilder sb=new StringBuilder();
        String[] cronSplit = cron.split(" ");

        for (int i = cronSplit.length-1; i >= 0;i--) {
            String c = cronSplit[i];
            if (i==0) {
                //秒
            }else if(i==1){
                //分钟
                if (!"*".equals(c) && !"?".equals(c)) {
                    String[] split = c.split(",");
                    for (String s : split) {
                        sb.append(new DecimalFormat("00").format(Integer.parseInt(s))).append("");
                    }
                }else{
                    sb.append("00");
                }
            }else if(i==2){
                //小时
                if (!"*".equals(c) && !"?".equals(c)) {
                    String[] split = c.split(",");
                    for (String s : split) {
                        sb.append(new DecimalFormat("00").format(Integer.parseInt(s))).append(":");
                    }
                }
            }else if(i==3){
                //天
                StringBuilder daySb=new StringBuilder();
                if (!"*".equals(c) && !"?".equals(c)) {
                    String[] split = c.split(",");
                    for (String s : split) {
                        daySb.append(s+"日").append(",");
                    }
                }
                if (StringUtils.isNotBlank(daySb)) {
                    sb.append(daySb.toString().substring(0,daySb.length()-1));
                }
            }else if(i==4){//目前不需要做月
            }else if(i==5){
                //周
                if (!"*".equals(c) && !"?".equals(c)) {
                    String[] split = c.split(",");
                    //sb.append("每周的 ");
                    for (String s : split) {
                        sb.append("周").append(NumberToCnUtil.toChineseLower(Integer.parseInt(s))).append(" ");
                    }
                }
            }
        }
        for (int i = 0; i < cronSplit.length; i++) {
            if (i==0) {
                //秒
            }else if(i==1){
                //分钟
            }else if(i==2){
                //小时
            }else if(i==3){
                //天
            }else if(i==4){//目前不需要做月
            }else if(i==5){
                //周
            }else if(i==6){
                //年 不需要
            }
        }
        System.out.println(sb);
        return sb.toString();
    }

}
